@@ -48,6 +48,11 @@ use XAO::Templates;
 
 use base XAO::Objects->load(objname => 'Web::Page');
 
+use vars qw($VERSION);
+$VERSION=(0+sprintf('%u.%03u',(q$Id: MenuBuilder.pm,v 2.1 2005/01/14 01:39:57 am Exp $ =~ /\s(\d+)\.(\d+)\s/))) || die "Bad VERSION";
+
+###############################################################################
+
 sub display ($;%) {
     my $self=shift;
     my $args=get_args(\@_);
@@ -140,9 +145,11 @@ Nothing.
 
 =head1 AUTHOR
 
-Copyright (c) 2000-2003 XAO, Inc.
+Copyright (c) 2005 Andrew Maltsev
 
-Andrew Maltsev <am@xao.com>.
+Copyright (c) 2001-2004 Andrew Maltsev, XAO Inc.
+
+<am@ejelta.com> -- http://ejelta.com/xao/
 
 =head1 SEE ALSO
 
