@@ -26,7 +26,7 @@ use base XAO::Objects->load(objname => 'Web::Page');
 ###############################################################################
 
 use vars qw($VERSION);
-($VERSION)=(q$Id: Styler.pm,v 1.9 2003/10/03 04:33:09 am Exp $ =~ /(\d+\.\d+)/);
+$VERSION=(0+sprintf('%u.%03u',(q$Id: Styler.pm,v 2.1 2005/01/14 01:39:57 am Exp $ =~ /\s(\d+)\.(\d+)\s/))) || die "Bad VERSION";
 
 sub separate_thousands ($);
 
@@ -133,9 +133,11 @@ Nothing.
 
 =head1 AUTHOR
 
-Copyright (c) 2000-2001 XAO, Inc.
+Copyright (c) 2005 Andrew Maltsev
 
-Andrew Maltsev <am@xao.com>.
+Copyright (c) 2001-2004 Andrew Maltsev, XAO Inc.
+
+<am@ejelta.com> -- http://ejelta.com/xao/
 
 =head1 SEE ALSO
 
